@@ -3,12 +3,18 @@
 from email.mime.base import MIMEBase
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
+from email.utils import parseaddr
 from email import encoders
+from imio.helpers import _
 from plone import api
+from Products.CMFDefault.exceptions import EmailAddressInvalid
+from Products.CMFDefault.utils import checkEmailAddress
 from Products.CMFPlone.utils import safe_unicode
 from smtplib import SMTPException
 from zope.component import getMultiAdapter
+from zope import schema
 
+import csv
 import logging
 import socket
 
@@ -17,13 +23,17 @@ EMAIL_CHARSET = 'utf-8'
 
 
 def get_email_charset():
-    """ Character set to use for encoding the email. """
+    """Character set to use for encoding the email."""
     portal = api.portal.get()
     return portal.getProperty('email_charset', EMAIL_CHARSET)
 
 
 def get_mail_host(check=False):
-    """ Get the MailHost object. """
+    """Get the MailHost object.
+
+    :param check: bool. Check if mailhost configuration is correct.
+    :return: MailHost tool
+    """
     if check:
         # check mailhost on 'smtp_host' and 'email_from_address'
         portal = api.portal.get()
@@ -37,10 +47,12 @@ def get_mail_host(check=False):
 
 
 def create_html_email(html, with_plain=True):
-    """ Returns an email message with an html body and optionally plain body
+    """ Returns an email message with an html body and optionally plain body.
+
     :param html: html body content
     :param with_plain: add plain text version (default=True)
     :return: MIMEMultipart instance
+    :rtype: MIMEMultipart
     """
     charset = get_email_charset()
     html = safe_unicode(html, charset)
@@ -75,7 +87,9 @@ def create_html_email(html, with_plain=True):
 
 @api.validation.at_least_one_of('filepath', 'content')
 def add_attachment(eml, filename, filepath=None, content=None):
-    """ Adds attachment to email instance
+    """ Adds attachment to email instance.
+    Must pass at least filepath or content.
+
     :param eml: email instance
     :param filename: file name string to store in header
     :param filepath: attachment file disk path
@@ -97,23 +111,25 @@ def add_attachment(eml, filename, filepath=None, content=None):
 
 def send_email(eml, subject, mfrom, mto, mcc=None, mbcc=None):
     """ Sends an email with MailHost.
+
     :param eml: email instance
     :param subject: subject string
     :param mfrom: from string
-    :param mto: to string or string list
-    :param mcc: cc string or string list
-    :param mbcc: bcc string or string list
-    :return: boolean status
+    :param mto: to string or string list or (name, address) list
+    :param mcc: cc string or string list or (name, address) list
+    :param mbcc: bcc string or string list or (name, address) list
+    :return: status
+    :rtype: bool
     """
     mail_host = get_mail_host()
     if mail_host is None:
         logger.error('Could not send email: mail host not well defined.')
-        return False
+        return False, 'Mail host not well defined'
 
     charset = get_email_charset()
     subject = safe_unicode(subject, charset)
     kwargs = {}
-    # put only as parameter id defined, so mockmailhost can be used in tests with secureSend as send patch
+    # put only as parameter if defined, so mockmailhost can be used in tests with secureSend as send patch
     if mcc is not None:
         kwargs['mcc'] = mcc
     if mbcc is not None:
@@ -123,10 +139,73 @@ def send_email(eml, subject, mfrom, mto, mcc=None, mbcc=None):
         # secureSend is deprecated and patched in Products/CMFPlone/patches/securemailhost.py
         # send remove from headers bcc !!
         mail_host.secureSend(eml, mto, mfrom, subject=subject, charset=charset, **kwargs)
-    except (socket.error, SMTPException):
-        logger.error('Could not send email to %s with subject %s', mto, subject)
-        return False
+    except (socket.error, SMTPException) as e:
+        logger.error("Could not send email to '{}' with subject '{}': {}".format(mto, subject, e))
+        return False, 'Could not send email : {}'.format(e)
     except Exception:
         raise
     # sent successfully
-    return True
+    return True, ''
+
+
+class InvalidEmailAddressFormat(schema.ValidationError):
+    """Exception for invalid address format with real name part."""
+    __doc__ = _(u"Invalid email address format: 'real name <email>' or 'email (real name)'")
+
+
+class InvalidEmailAddress(schema.ValidationError):
+    """Exception for invalid address.
+       `doc` method is used to return a dynamic message with real tested address.
+    """
+
+    def __init__(self, eml, *args, **kwargs):
+        self.eml = eml
+
+    def doc(self):
+        return _(u"Invalid email address: '${eml}'", mapping={'eml': self.eml})
+
+
+def validate_email_address(value):
+    """Email validator for email address with possible real name part.
+
+    :param value: email value
+    :return: tuple containing real name and address
+    :rtype: tuple
+    """
+    if not value:
+        return True
+    eml = safe_unicode(value)
+    realname = u''
+    complex_form = True in [b in eml and e in eml for b, e in ('<>', '()')]
+    # Use parseaddr only when necessary to avoid correction like 'a @d.c' => 'a@d.c'
+    # or to avoid bad split like 'a<a@d.c' => 'a@d.c'
+    if complex_form:
+        realname, eml = parseaddr(eml)
+        if not realname and not eml:
+            raise InvalidEmailAddressFormat(value)
+        # we check if the email has not been corrected by parseaddr, removing some characters like space
+        if eml not in value:
+            raise InvalidEmailAddress(u"'{}' => '{}' ?".format(value, eml))
+    try:
+        checkEmailAddress(eml)
+    except EmailAddressInvalid:
+        raise InvalidEmailAddress(eml)
+    return realname, eml
+
+
+def validate_email_addresses(value):
+    """Email validator for email addresses (with possible real name part) separated by ','.
+
+    :param value: email value
+    :return: True
+    """
+    if not value:
+        return True
+    ret = []
+    # we need to multiply doublequotes, otherwise they are removed by csv
+    value = value.replace('"', '"""')
+    # split addresses using csv
+    for line in csv.reader([value], delimiter=',', quotechar='"', skipinitialspace=True):
+        for eml in line:
+            ret.append(validate_email_address(eml))
+    return ret
