@@ -14,6 +14,8 @@ from imio.helpers.content import get_schema_fields
 from imio.helpers.content import get_state_infos
 from imio.helpers.content import get_vocab
 from imio.helpers.content import normalize_name
+from imio.helpers.content import object_values
+from imio.helpers.content import object_ids
 from imio.helpers.content import restore_link_integrity_checks
 from imio.helpers.content import richtextval
 from imio.helpers.content import safe_delattr
@@ -22,6 +24,8 @@ from imio.helpers.content import set_to_annotation
 from imio.helpers.content import transitions
 from imio.helpers.content import uuidsToCatalogBrains
 from imio.helpers.content import uuidsToObjects
+from imio.helpers.content import uuidToCatalogBrain
+from imio.helpers.content import uuidToObject
 from imio.helpers.content import validate_fields
 from imio.helpers.testing import IntegrationTestCase
 from plone import api
@@ -289,6 +293,16 @@ class TestContentModule(IntegrationTestCase):
             uuidsToObjects(uuids, ordered=True),
             [self.portal.folder2, self.portal.folder])
 
+    def test_uuidToCatalogBrain(self):
+        folder_uid = self.portal.folder.UID()
+        single_brain = uuidToCatalogBrain(folder_uid)
+        self.assertEqual(single_brain.UID, folder_uid)
+
+    def test_uuidToObject(self):
+        folder_uid = self.portal.folder.UID()
+        single_obj = uuidToObject(folder_uid)
+        self.assertEqual(single_obj.UID(), folder_uid)
+
     def test_disable_link_integrity_checks(self):
         self.assertTrue(self.portal.portal_properties.site_properties.enable_link_integrity_checks)
         disable_link_integrity_checks()
@@ -359,3 +373,11 @@ class TestContentModule(IntegrationTestCase):
                          'cv-informaticien-ndeg2016-1')
         self.assertEqual(normalize_name(request, u'Héhé du texte'),
                          'hehe-du-texte')
+
+    def test_object_values(self):
+        self.assertEqual(object_values(self.portal, 'Folder'), [])
+        self.assertEqual(object_values(self.portal, 'ATFolder'), [self.portal.folder, self.portal.folder2])
+
+    def test_object_ids(self):
+        self.assertEqual(object_ids(self.portal, 'Folder'), [])
+        self.assertEqual(object_ids(self.portal, 'ATFolder'), ['folder', 'folder2'])
